/****************************************************************************************************************
   Program: 240_create_nhc24_rural.sas

   Purpose: This program uses the geocoded, most recent month of publicly available Nursing Home Compare data
            (the output file from the 237 program) to assign facilities to Rural-Urban Commuting Area (RUCA)
            codes and to construct a binary rural variable based on the RUCA values.  It uses the publicly
            available 2010 census tract to RUCA code crosswalk available from the U.S. Department of Agriculture
            (https://www.ers.usda.gov/data-products/rural-urban-commuting-area-codes/documentation). In this
            program, the code also crosswalks the SSA county codes from Nursing Home Compare to FIPS county
            codes using publicly available crosswalk from the National Bureau of Economic Research 
            (https://www.nber.org/research/data/ssa-federal-information-processing-series-fips-state-
            and-county-crosswalk).

   Input files: ruca_xwalk.sas7bdat
                nhc_2024.sas7bdat
                nhc_2024_tracts.sas7bdat
                ssa_fips_state_county_2023.sas7bdat

   Output files: nhc_2024_w_rural.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in_nhc "<y2 input directory>" access=readonly;
libname in_ruca "<y1 input directory>" access=readonly;
libname out "<output directory>";

%let in_nhc = in_nhc.nhc_2024;
%let in_tract = in_nhc.nhc_2024_tracts;
%let in_ruca = in_ruca.ruca_xwalk;
%let in_fips = in_nhc.ssa_fips_state_county_2023;
%let outfile = out.nhc_2024_w_rural;

data ruca_xwalk(rename=(tract_fips_cd = nhc24_tract_fips_cd
                        primary_ruca_cd = nhc24_primary_ruca
                        secondary_ruca_cd = nhc24_secondary_ruca));
   set &in_ruca.(keep=tract_fips_cd primary_ruca_cd secondary_ruca_cd);

   if 1 <= primary_ruca_cd <= 6 then nhc24_rural = 0;
   else if 7 <= primary_ruca_cd <= 10 then nhc24_rural = 1;
   else nhc24_rural = .;

run;

data nhc_full;
   set &in_nhc.;
run;

proc sort data=nhc_full;
   by nhc24_prov_state nhc24_prov_cnty_cd;
run;

data ssa_to_fips(drop=ssa_code fipscounty);
   set &in_fips.(keep=state ssa_code fipscounty countyname_fips
                 rename=(state = nhc24_prov_state));

   length nhc24_prov_cnty_cd $ 3 nhc24_nber2023_county_fips_cd $ 5;

   nhc24_prov_cnty_cd = substr(ssa_code,3,3);
   nhc24_nber2023_county_fips_cd = put(fipscounty,z5.);

run;

proc sort data=ssa_to_fips nodupkey;
   by nhc24_prov_state nhc24_prov_cnty_cd nhc24_nber2023_county_fips_cd;
run;

proc sql noprint;
   create table nhc_full_ssa as
   select a.*, b.nhc24_nber2023_county_fips_cd, b.countyname_fips
   from nhc_full a left join ssa_to_fips b
   on a.nhc24_prov_state = b.nhc24_prov_state and
      a.nhc24_prov_cnty_cd = b.nhc24_prov_cnty_cd
    order by a.nhc24_ccn;
quit;

data nhc_full_ssa(drop=countyname_fips)
     nhc_ssa_cnty_mismatch(keep=nhc24_ccn);
   set nhc_full_ssa;
   by nhc24_ccn;

   if first.nhc24_ccn and last.nhc24_ccn then output nhc_full_ssa;
   else do;
      if upcase(nhc24_prov_cnty_name) = upcase(countyname_fips) then output nhc_full_ssa;
      else output nhc_ssa_cnty_mismatch;
   end;

run;

proc sort data=nhc_full_ssa out=dupchk1 nodupkey; /* Should be none removed */
   by nhc24_ccn;
run;

proc sort data=nhc_ssa_cnty_mismatch out=dupchk2 nodupkey; /* Should be none removed */
   by nhc24_ccn;
run;

data nhc_tract;
   set &in_tract.(rename=(geoid = nhc24_tract_fips_cd
                          match = nhc24_tract_match));
run;

proc sort data=nhc_tract;
   by nhc24_tract_fips_cd;
run;

data nhc_tract_ruca;
   merge nhc_tract(in=a) ruca_xwalk;
   by nhc24_tract_fips_cd;
   if a;
run;

proc sort data=nhc_tract_ruca;
   by nhc24_ccn;
run;

data &outfile.;
   merge nhc_full_ssa nhc_tract_ruca;
   by nhc24_ccn;
run;