/****************************************************************************************************************
   Program Name: 410_avg_daily_census.sas

   Description: This program calculates the average daily census overall and for people living with dementia and  
                by race and ethnicity among all facilities in the current MDS. It also merges the MDS facility-level 
                file with average daily census to the file with LTC Focus and Nursing Home Compare data and constructs a file with all 
                facilities found in the current MDS and the the most current month of Nursing Home Compare.  
				
   Input files: Current and prior year MDS assessments prepared in 400_process_mds.sas
				  _400_mds_{yyyy}.sas7bdat
                LTC Focus and Nursing Home Compare data
				  all_nh_facilities.sas7bdat

   Output files: _410_avg_daily_census.sas7bdat
****************************************************************************************************************/
options validvarname=upcase mergenoby=error compress=yes;
options mprint symbolgen obs=max nocenter ls=154 ps=58 minoperator;

/**************************************************************************************
 Set the current and prior year MDS assessments together and prepare for calculating
 the average daily census. 
**************************************************************************************/

data mds_&prior_year._&year.;
	set &indata._&year. &indata._&prior_year.;

	/* Flag entry assessments for sorting stays */
	entered_nh = 0;
    if a0310f_entry_dschrg_cd = "01" then entered_nh = 1;

	/* Flag discharge assessments for sorting stays */
	left_nh = 0;
    if a0310f_entry_dschrg_cd in ("10" "11") then left_nh = 1;
run;

proc sort data = mds_&prior_year._&year.;
	by a0100b_cms_crtfctn_num bene_id descending trgt_dt descending died descending left_nh entered_nh;
run;

/**************************************************************************************
 Identify when the beneficiary was discharged from the facility. If the entry/discharge
 status code indicates the beneficiary died (12) or was discharged (10,11) set their
 facility stay end date to the target date. Otherwise if there is no other assessment within 
 150 days and the last assessment occurred on or before August 3 of the current year, 
 set their facility stay end date to the target date plus 150 days. 
**************************************************************************************/

data mds_w_dschrg_&prior_year._&year.;
	set mds_&prior_year._&year.;

	by a0100b_cms_crtfctn_num bene_id;
	retain prev_trgt_dt;

	if first.bene_id then do;
		subsequent_record_wi_150_days = .;
	end;
	else do;
		if intck('day', trgt_dt, prev_trgt_dt) <= 150 then subsequent_record_wi_150_days = 1;
		else subsequent_record_wi_150_days = 0;
	end;
	prev_trgt_dt = trgt_dt;

	if a0310f_entry_dschrg_cd in ("10", "11") then discharged = 1;
	else if a0310f_entry_dschrg_cd not in ("10", "11", "12") and trgt_dt <= mdy(8,3,&year.) and subsequent_record_wi_150_days ne 1 then discharged = 2;
	else discharged = 0;

	format prev_trgt_dt end_dt date9.;
	if died = 1 or discharged = 1 then end_dt = trgt_dt;
	else if discharged = 2 then end_dt = intnx('day', trgt_dt, 150);

	gone = (died = 1 or discharged in (1, 2));
	missing_bene_id = (missing(bene_id));
	missing_trgt_dt = (missing(trgt_dt));
	missing_end_dt = (missing(end_dt));
	drop prev_trgt_dt;
run;

/**************************************************************************************
 Create a stayid to identify all assessments that were part of the same stay for the 
 same resident in a facility.
**************************************************************************************/

proc sort data = mds_w_dschrg_&prior_year._&year.;
	by a0100b_cms_crtfctn_num bene_id trgt_dt gone died discharged;
run;

data mds_w_stayid_&prior_year._&year.;
	set mds_w_dschrg_&prior_year._&year.;
	by a0100b_cms_crtfctn_num bene_id;
	retain prev_stayid prev_stayid_seq prev_gone prev_trgt_dt;
	switch_1_to_0 = 0;
	if _N_ = 1 then prev_stayid = 0;
	if first.bene_id then do;
		stayid = prev_stayid + 1;
		stayid_seq = 1;
	end;
	else do;
		if prev_gone = 1 and prev_trgt_dt ne trgt_dt then do;
			stayid = prev_stayid + 1;
			stayid_seq = 1;
			if gone = 0 then switch_1_to_0 = 1;
		end;
		else do;
			stayid = prev_stayid;
			stayid_seq = prev_stayid_seq + 1;
		end;
	end;
	prev_stayid = stayid;
	prev_stayid_seq = stayid_seq;
	prev_gone = gone;
	prev_trgt_dt = trgt_dt;
run;

proc sql;
	create table mds_w_stayid2_&prior_year._&year. as
	select *,
	 	   min(trgt_dt) as min_tgt_dt format = date9.,
	 	   max(end_dt) as max_end_dt format = date9.
	from mds_w_stayid_&prior_year._&year. (drop = prev_:) as a
	group by stayid
	order by a0100b_cms_crtfctn_num, bene_id, trgt_dt, stayid, stayid_seq;
quit;

/**************************************************************************************
 Collapse file to the stayid level
**************************************************************************************/

data mds_w_stayid2_&prior_year._&year.;
	set mds_w_stayid2_&prior_year._&year.;
	if not missing(max_end_dt) and max_end_dt < mdy(1,1,&year.) then delete;
run;

proc sql;
	create table mds_stayid_clps_&year. (drop = max_stayid_seq) as 
	select *, sum(intck('day', firstday_&year. , lastday_&year.), 1) as tot_days
	from
	(
	select a.*,
		   b.a1000a_amrcn_indn_ak_ntv_cd,
		   b.a1000b_asn_cd,
		   b.a1000c_afrcn_amrcn_cd,
		   b.a1000d_hspnc_cd,
		   b.a1000e_ntv_hi_pcfc_islndr_cd,
		   b.a1000f_wht_cd,
		   case when min_tgt_dt <= mdy(1,1,&year.) then mdy(1,1,&year.) else min_tgt_dt end as firstday_&year. format = date9.,
		   case when not missing(max_end_dt) then max_end_dt else mdy(12,31,&year.) end as lastday_&year. format = date9.
	from (select a0100b_cms_crtfctn_num,
		   		 bene_id,
		   		 stayid,
				 exclude,
			     min_tgt_dt,
			     max_end_dt,
				 max(stayid_seq) as max_stayid_seq,
			     max(dement) as dement,
			     max(gone) as gone,
			     max(died) as died,
			     max(discharged) as discharged
		  from mds_w_stayid2_&prior_year._&year.
		  group by a0100b_cms_crtfctn_num, bene_id, stayid, exclude, min_tgt_dt, max_end_dt) as a
	left join
	(select a0100b_cms_crtfctn_num,
		   	bene_id,
		   	stayid,
		   	stayid_seq,
			a1000a_amrcn_indn_ak_ntv_cd,
			a1000b_asn_cd,
			a1000c_afrcn_amrcn_cd,
			a1000d_hspnc_cd,
			a1000e_ntv_hi_pcfc_islndr_cd,
			a1000f_wht_cd
	 from mds_w_stayid2_&prior_year._&year.) as b
	on a.a0100b_cms_crtfctn_num = b.a0100b_cms_crtfctn_num and a.bene_id = b.bene_id and a.stayid = b.stayid and a.max_stayid_seq = b.stayid_seq
	);
quit;

/**************************************************************************************
 Collapse the file to the facility level and calculate average daily census.
**************************************************************************************/

proc sql;
	create table mds_census_&year. as
	select a0100b_cms_crtfctn_num,
		   exclude,
		   sum(tot_days) as fac_census_all label = "Total Number of Resident Days in the Year",
		   sum(case when dement = 1 then tot_days else 0 end) as fac_census_all_dement label = "Total Number of Resident Days Among Residents with Dementia in the Year",
		   sum(case when a1000f_wht_cd = "1" then tot_days else 0 end) as fac_census_wht label = "Total Number of Resident Days Among White Residents in the Year",
		   sum(case when a1000f_wht_cd = "1" and dement = 1 then tot_days else 0 end) as fac_census_wht_dement label = "Total Number of Resident Days Among White Residents with Dementia in the Year",
		   count(distinct bene_id) as fac_num_res label = "Number of Unique Patients Served by Facility During the Year",
		   count(distinct case when dement = 1 then bene_id else . end) as fac_num_res_dement label = "Number of Unique Patients with Dementia Served by Facility During the Year"
	from mds_stayid_clps_&year. 
	group by a0100b_cms_crtfctn_num, exclude;
quit;

data mds_census_&year.;
	set mds_census_&year.;
	if missing(a0100b_cms_crtfctn_num) then delete; 
	fac_census_nonwht = sum(fac_census_all, -fac_census_wht);
	fac_census_nonwht_dement = sum(fac_census_all_dement, -fac_census_wht_dement);
	avg_daily_census_all = fac_census_all / 365;
	avg_daily_census_dmt = fac_census_all_dement / 365;
	avg_daily_census_wht = fac_census_wht / 365;
	avg_daily_census_wht_dmt = fac_census_wht_dement / 365;
	avg_daily_census_nonwht = fac_census_nonwht / 365;
	avg_daily_census_nonwht_dmt = fac_census_nonwht_dement / 365;
	if fac_num_res ne 0 then pct_dement_rsdnts = fac_num_res_dement / fac_num_res;
	if avg_daily_census_all ne 0 then pct_dement_days = avg_daily_census_dmt / avg_daily_census_all;
	if avg_daily_census_all ne 0 then pct_nonwht_days = avg_daily_census_nonwht / avg_daily_census_all;
	if avg_daily_census_dmt ne 0 then pct_nonwht_dement_days = avg_daily_census_nonwht_dmt / avg_daily_census_dmt;
	no_dement_days = (fac_census_all_dement = 0);
	mds = 1;
	label fac_census_nonwht = "Total Number of Resident Days Among Non-White Residents in the Year"
		  fac_census_nonwht_dement = "Total Number of Resident Days Among Non-White Residents with Dementia in the Year"
		  avg_daily_census_all = "Average Daily Census in the Facility"
		  avg_daily_census_dmt = "Average Daily Census of Residents with Dementia in the Facility"
		  avg_daily_census_wht = "Average Daily Census of White Residents in the Facility"
		  avg_daily_census_wht_dmt = "Average Daily Census of White Residents with Dementia in the Facility"
		  avg_daily_census_nonwht = "Average Daily Census of Non-White Residents in the Facility"
		  avg_daily_census_nonwht_dmt = "Average Daily Census of Non-White Residents with Dementia in the Facility"
		  pct_dement_rsdnts = "Percent of Residents Who Ever Stays at the NH in the Year with Dementia"
		  pct_dement_days = "Percent of Resident Days with Dementia in the Facility"
		  pct_nonwht_days = "Percent of Resident Days Who Are Non-White in the Facility"
		  pct_nonwht_dement_days = "Percent of Dementia Resident Days Who Are Non-White in the Facility"
		  mds = "Facility in MDS Data"
		  no_dement_days = "CCN Does Not Have Dementia Days";
	;
run;

/**************************************************************************************
 Read in and de-duplicate the file with LTC Focus and Nursing Home Compare data
**************************************************************************************/

proc sort data=&master_nh_file. out=ccn_file_&year.; 
  by ccn; 
run;

data dupes_in_ccn_file_&year.;
  set ccn_file_&year.;
  by ccn;
  if first.ccn and last.ccn then delete;
run;

data ccn_file_&year.;
  set ccn_file_&year.;
  by ccn;
  if first.ccn;
run;

/**************************************************************************************
 Merge the MDS file with average daily census to the deduplicated file with LTC Focus 
 and Nursing Home Compare data
**************************************************************************************/

proc sort data=mds_census_&year. (rename=(a0100b_cms_crtfctn_num = ccn)) out=mds_ccn_&year.; 
  by ccn; 
run;

data mds_ccn_&year.;
  merge mds_ccn_&year. (in=_inmds) 
        ccn_file_&year. (in=_inccn);
  by ccn;
  InMDS = _inmds;
  InNHMaster = _inccn;
  rename in_ltcf = has_ltcf
         in_nhc&yr2. = has_nhc&yr2.
		 in_nhc&yrsf2. = has_nhc&yrsf2.
		 ;
run;

/**************************************************************************************
 Separate the facilities into files based on whether its CCN is in both the MDS and 
 LTCH/NHC files or in only one of the two files
**************************************************************************************/

data sampframe
     mds_not&year_sf.
	 nhc&yrsf2._notmds
	 allothers;
  set mds_ccn_&year. (drop=InMDS InNHMaster);

  /* If the facility is in the MDS and has a record in the most recent Nursing Home 
     Compare data, output to sampframe */
  if mds = 1 and has_nhc&yrsf2. = 1 then output sampframe;

  /* If the facility is in the MDS and does not have a record in the most current 
     Nursing Home Compare data, output to mds_not{current NHC} */
  else if mds = 1 then output mds_not&year_sf.;

  /* If the facility is not in MDS but has a record in the most current Nursing Home
     Compare data, output to nhc(current NHC)_notmds */
  else if missing(mds) and has_nhc&yrsf2. = 1 then output nhc&yrsf2._notmds;

  /* Otherwise output facility to allothers - these are facilities found only in LTC
     Focus or only in Nursing Home Compare in the MDS year */
  else output allothers;
run;

/**************************************************************************************
 Identify facilities that changed ownership between the MDS year and the most current 
 NHC. These are facilities that have the same address and zip code, but did not merge 
 on CCN above (i.e., these facilities CCNs changed between the MDS year and most current
 NHC year). 
**************************************************************************************/

data mds_not&year_sf._x_owner;
  set mds_not&year_sf.;
  keep ccn 
       nhc&yr2._prov_addr 
       nhc&yr2._prov_zip 
       nhc&yr2._prov_name
	   nhc&yr2._prov_type 
       nhc&yr2._resides_in_hospital 
       nhc&yr2._cont_care_rtrmnt_cmnty
	   nhc&yr2._avg_nmbr_rsdnts_per_day_fn 
       nhc&yr2._nmbr_crtfd_beds 
       nhc&yr2._ownership_type
	   nhc&yr2._changed_owner_lst12mnths
	   ltc_prov_addr
	   ltc_prov_zip
	   ltc_prov_name
	   ltc_profit
	   ltc_totbeds
	   addr_zip
	   ;
  rename ccn = ccn&yr2.;

  length addr_zip $75;

  if has_nhc&yr2. = 1 then addr_zip = catx('-', nhc&yr2._prov_addr, nhc&yr2._prov_zip);
  else if has_ltcf = 1 then addr_zip = catx('-', ltc_prov_addr, ltc_prov_zip);

  /* Drop facilities only in MDS - we do not have addresses for these facilities */
  if missing(has_nhc&yr2.) and missing(has_ltcf) then delete;
run;

data nhc&yrsf2._notmds_x_owner;
  set nhc&yrsf2._notmds;
  keep ccn 
       nhc&yrsf2._prov_addr 
       nhc&yrsf2._prov_zip 
       nhc&yrsf2._prov_name
	   nhc&yrsf2._prov_type 
       nhc&yrsf2._resides_in_hospital 
       nhc&yrsf2._cont_care_rtrmnt_cmnty
	   nhc&yrsf2._avg_nmbr_rsdnts_per_day_fn 
       nhc&yrsf2._nmbr_crtfd_beds 
       nhc&yrsf2._ownership_type
	   nhc&yrsf2._changed_owner_lst12mnths
	   addr_zip
	   ;
  rename ccn = ccn&yrsf2.;

  length addr_zip $75;

  if has_nhc&yrsf2. = 1 then addr_zip = catx('-', nhc&yrsf2._prov_addr, nhc&yrsf2._prov_zip);
run;

proc sort data=mds_not&year_sf._x_owner; 
  by addr_zip; 
run;

proc sort data=nhc&yrsf2._notmds_x_owner; 
  by addr_zip; 
run;

data ccn_changed_same_addr;
  merge mds_not&year_sf._x_owner (in=m)
        nhc&yrsf2._notmds_x_owner (in=n);
  by addr_zip;
  if m and n;
run;

/**************************************************************************************
 Update the sampframe file to include the facilities we found that changed ownership and 
 remove them from the mds_not{sample frame year) and nhc{year}_notmds files so we
 can track the file counts.

 Delete the CCN (445536) that was a Medicare and Medicaid certified unit that 
 disappeared by 2024.
**************************************************************************************/

data ccn_x_owners;
  set ccn_changed_same_addr (keep=ccn&yr2. ccn&yrsf2.);
  if ccn&yr2. = "445536" then delete;
  ccn = ccn&yr2.;
run;

proc sort data=ccn_x_owners;
  by ccn;
run;

proc sort data=mds_not&year_sf.;
  by ccn;
run;

data mds_not&year_sf._updated
     for_sampframe_mds_&year. (drop=nhc&yrsf2.: has_nhc&yrsf2. rename=(ccn = ccn&yr2.));
  merge ccn_x_owners (in=x keep=ccn)
        mds_not&year_sf. (in=mds_not);
  by ccn;
  if x and mds_not then output for_sampframe_mds_&year.;
  else output mds_not&year_sf._updated;
run;

proc sort data=ccn_x_owners (keep=ccn&yr2. ccn&yrsf2.) out=ccn_to_add (rename=(ccn&yrsf2. = ccn));
  by ccn&yrsf2.;
run;

data nhc&yrsf2._notmds_updated
     for_sampframe_nhc&yrsf2. (keep=ccn ccn&yr2. nhc&yrsf2.: has_nhc&yrsf2.);
  merge ccn_to_add (in=x)
        nhc&yrsf2._notmds (in=not_mds);
  by ccn;
  if x and not_mds then output for_sampframe_nhc&yrsf2.;
  else output nhc&yrsf2._notmds_updated;
run;

proc sort data=for_sampframe_mds_&year.;
  by ccn&yr2.;
run;

proc sort data=for_sampframe_nhc&yrsf2.;
  by ccn&yr2.;
run;

data for_sampframe;
  merge for_sampframe_mds_&year. (in=a)
        for_sampframe_nhc&yrsf2. (in=b);
  by ccn&yr2.;
  if a and b;
run;

data sampframe_updated;
  set sampframe
      for_sampframe (in=added);
  ccn_x_ownership = added;
run;

/**************************************************************************************
 Flag facilities that have the same name and zip code or address and zip code, but 
 different CCNs, indicating that they are likely located on the same campus. Also 
 create an ID variable so the sampling team can track these facilities
**************************************************************************************/

/**************************************************************************************
 Finding facilities with the same address and zip code
**************************************************************************************/

proc sql;
  create table same_addr_zip as
  select nhc&yrsf2._prov_addr
        ,nhc&yrsf2._prov_zip
        ,count(distinct ccn) as num_ccns
  from sampframe_updated
  group by nhc&yrsf2._prov_addr
          ,nhc&yrsf2._prov_zip;
quit;

data same_addr_zip;
  set same_addr_zip;
  if missing(nhc&yrsf2._prov_addr) then delete;
  same_fac_addr = 0;
  same_fac_id_addr = 0;
  if num_ccns > 1 then do;
 	same_fac_addr = 1;
	same_fac_id_addr = _N_;
  end;
run;

/**************************************************************************************
 Finding facilities with the same name and zip code 
**************************************************************************************/

proc sql;
  create table same_name_zip as
  select nhc&yrsf2._prov_name
        ,nhc&yrsf2._prov_zip
        ,count(distinct ccn) as num_ccns
  from sampframe_updated
  group by nhc&yrsf2._prov_name
          ,nhc&yrsf2._prov_zip;
quit;

data same_name_zip;
  set same_name_zip;
  if missing(nhc&yrsf2._prov_name) then delete;
  same_fac_name = 0;
  same_fac_id_name = 0;
  if num_ccns > 1 then do;
    same_fac_name = 1;
    same_fac_id_name = _N_;
  end;
run;

/**************************************************************************************
 Create an indicator variable for facilities with the same address/zip or same name/zip
 but different CCNs, and create an id variable to identify facilities that share these 
 characteristics.
**************************************************************************************/

proc sql;
  create table sampframe_same_fac as
  select a.*
        ,b.same_fac_addr
        ,b.same_fac_id_addr
		,c.same_fac_name
        ,c.same_fac_id_name
  from sampframe_updated as a

  left join same_addr_zip as b
       on a.nhc&yrsf2._prov_addr = b.nhc&yrsf2._prov_addr
      and a.nhc&yrsf2._prov_zip = b.nhc&yrsf2._prov_zip

  left join same_name_zip as c
       on a.nhc&yrsf2._prov_name = c.nhc&yrsf2._prov_name
      and a.nhc&yrsf2._prov_zip = c.nhc&yrsf2._prov_zip;
quit;

data sampframe_same_fac;
  set sampframe_same_fac;
  if same_fac_addr = 1 or same_fac_name = 1 then same_fac = 1;
  if same_fac_addr = 0 and same_fac_name = 0 then same_fac = 0;

  if same_fac_addr = 1 then same_fac_id = same_fac_id_addr;
  else if same_fac_name = 1 then same_fac_id = same_fac_id_name;
run;

proc sort data=sampframe_same_fac; 
  by same_fac_id; 
run;

/**************************************************************************************
 Drop swing bed facilities (none found in current MDS) or facilities located in US 
 territories
**************************************************************************************/

data sampframe_same_fac;
  set sampframe_same_fac;
  outofusa = 0;
  if nhc&yrsf2._prov_state in ('PR' 'GU' 'VI' 'MP' 'AS') then outofusa = 1;
  if exclude = 0;
run;

data sampframe_same_fac;
  set sampframe_same_fac;
  if exclude = 0 and outofusa = 0;
run;

/**************************************************************************************
  Output Sample Frame file
**************************************************************************************/

proc sort data=sampframe_same_fac out=&outdata.;
  by ccn;
run;

/**************************************************************************************
  Mask small cell sizes
**************************************************************************************/

data &outdata.; 
  set &outdata.;

  /* Suppress cells with denominators with 1-10 patients */
  if 0 < fac_census_all <= 10 then avg_daily_census_all = .S;
  if 0 < fac_census_all_dement <= 10 then avg_daily_census_dmt = .S;
  if 0 < fac_census_wht <= 10 then avg_daily_census_wht = .S;
  if 0 < fac_census_wht_dement <= 10 then avg_daily_census_wht_dmt = .S;
  if 0 < fac_census_nonwht <= 10 then avg_daily_census_nonwht = .S;
  if 0 < fac_census_nonwht_dement <= 10 then avg_daily_census_nonwht_dmt = .S;

  if fac_census_wht > 10 and 0 < fac_census_nonwht <= 10 then fac_census_wht = .S;
  if fac_census_nonwht > 10 and 0 < fac_census_wht <= 10 then fac_census_nonwht = .S;

  if fac_census_wht_dement > 10 and 0 < fac_census_nonwht_dement <= 10 then fac_census_wht_dement = .S;
  if fac_census_nonwht_dement > 10 and 0 < fac_census_wht_dement <= 10 then fac_census_nonwht_dement = .S;

  if fac_census_all > 10 and fac_census_all_dement <= 10 then pct_dement_days = .S;
  if fac_census_all > 10 and fac_census_nonwht <= 10 then pct_nonwht_days = .S;
  if fac_census_all_dement > 10 and fac_census_nonwht_dement <= 10 then pct_nonwht_dement_days = .S;
  if fac_num_res > 10 and 0 < fac_num_res_dement <= 10 then pct_dement_rsdnts = .S;

  /* Set missings to .M */
  %macro reset_miss(var=);
  if &var. = . then &var.= .M;
  %mend reset_miss;

  %reset_miss(var=AVG_DAILY_CENSUS_ALL);
  %reset_miss(var=AVG_DAILY_CENSUS_DMT);       
  %reset_miss(var=FAC_CENSUS_ALL);             
  %reset_miss(var=FAC_CENSUS_ALL_DEMENT);      
  %reset_miss(var=FAC_CENSUS_WHT);             
  %reset_miss(var=FAC_CENSUS_WHT_DEMENT);      
  %reset_miss(var=FAC_NUM_RES);                
  %reset_miss(var=FAC_NUM_RES_DEMENT);         
  %reset_miss(var=FAC_CENSUS_NONWHT);          
  %reset_miss(var=FAC_CENSUS_NONWHT_DEMENT);   
  %reset_miss(var=AVG_DAILY_CENSUS_WHT);       
  %reset_miss(var=AVG_DAILY_CENSUS_WHT_DMT);   
  %reset_miss(var=AVG_DAILY_CENSUS_NONWHT);    
  %reset_miss(var=AVG_DAILY_CENSUS_NONWHT_DMT);
  %reset_miss(var=PCT_DEMENT_RSDNTS);          
  %reset_miss(var=PCT_DEMENT_DAYS);            
  %reset_miss(var=PCT_NONWHT_DAYS);            
  %reset_miss(var=PCT_NONWHT_DEMENT_DAYS); 

  /* Set small cell sizes to .E */
  %macro small_cell(var=);
  if 1 <= &var. <= 10 then &var.= .E;
  %mend small_cell;

  %small_cell(var=FAC_CENSUS_ALL);             
  %small_cell(var=FAC_CENSUS_ALL_DEMENT);      
  %small_cell(var=FAC_CENSUS_WHT);             
  %small_cell(var=FAC_CENSUS_WHT_DEMENT);      
  %small_cell(var=FAC_NUM_RES);                
  %small_cell(var=FAC_NUM_RES_DEMENT);         
  %small_cell(var=FAC_CENSUS_NONWHT);          
  %small_cell(var=FAC_CENSUS_NONWHT_DEMENT);   
run;
