/****************************************************************************************************************
   Program: 420_nh_sample_frame.sas

   Purpose: This program reads in both the year one and year two sample frames and identifies facilities whose 
            CCN changed between year one and year two. It adds the year one CCN and a flag noting the change onto
            the year two file so that the sampling team can track facilities over time. Finally, the program 
            reorders variables to put the important variables for sampling first and drops variables that are no 
            longer needed. 

   Input files: _410_avg_daily_census.sas7bdat - Y2 sample frame
                nh_frame_20240522.sas7bdat - Y1 sample frame

   Output files: NH_frame_y2_{yyyymmdd}.sas7bdat
                 NH_frame_y2_{yyyymmdd}.xlsx
****************************************************************************************************************/
options nocenter mprint obs=max compress=yes;

libname in "<Y2 input directory>" access=readonly;
libname out "<Y2 output directory>";

libname y1 "<Y1 input directory>" access=readonly;

%let dt=%sysfunc(today(),yymmddn8.);

%let infile = in._410_avg_daily_census;
%let y1file = y1.nh_frame_20240522;

%let outfile = out.NH_frame_y2_&dt.;

%let xlsfile = "<Y2 output directory>\NH_frame_y2_&dt..xlsx";

***********************************************************************
 Read in sample frames.
*********************************************************************** ;

data y1;
  set &y1file.;
run;

data y2;
  set &infile.;
run;

***********************************************************************
*-- Identify CCNs for the same facility that changed between Y1 and Y2. 
    Create a flag and a variable containing their Y1 CCN.
*********************************************************************** ;

proc sql;
  create table y1_y2 as
  select y1.ccn as Y1_CCN
        ,y1.nhc24_prov_addr as y1_nhc24_prov_addr
        ,y1.nhc24_prov_zip as y1_nhc24_prov_zip 
        ,y1.nhc24_prov_name as y1_nhc24_prov_name
	    ,y1.nhc24_prov_type as y1_nhc24_prov_type 
        ,y1.nhc24_resides_in_hospital as y1_nhc24_resides_in_hospital 
        ,y1.nhc24_cont_care_rtrmnt_cmnty as y1_nhc24_cont_care_rtrmnt_cmnty
	    ,y1.nhc24_avg_nmbr_rsdnts_per_day_fn as y1_nhc24_avg_nmbr_res_per_day_fn 
        ,y1.nhc24_nmbr_crtfd_beds as y1_nhc24_nmbr_crtfd_beds 
        ,y1.nhc24_ownership_type as y1_nhc24_ownership_type
	    ,y1.nhc24_changed_owner_lst12mnths as y1_nhc24_changed_owner_lst12mnth
        ,y2.ccn as Y2_CCN
        ,y2.nhc24_prov_addr as y2_nhc24_prov_addr
        ,y2.nhc24_prov_zip as y2_nhc24_prov_zip 
        ,y2.nhc24_prov_name as y2_nhc24_prov_name
	    ,y2.nhc24_prov_type as y2_nhc24_prov_type 
        ,y2.nhc24_resides_in_hospital as y2_nhc24_resides_in_hospital 
        ,y2.nhc24_cont_care_rtrmnt_cmnty as y2_nhc24_cont_care_rtrmnt_cmnty
	    ,y2.nhc24_avg_nmbr_rsdnts_per_day_fn as y2_nhc24_avg_nmbr_res_per_day_fn 
        ,y2.nhc24_nmbr_crtfd_beds as y2_nhc24_nmbr_crtfd_beds 
        ,y2.nhc24_ownership_type as y2_nhc24_ownership_type
	    ,y2.nhc24_changed_owner_lst12mnths as y2_nhc24_changed_owner_lst12mnth
		,case when ~missing(y1.ccn) then 1 else 0 end as InY1
		,case when ~missing(y2.ccn) then 1 else 0 end as InY2
  from y1 as y1
  full outer join y2 as y2
    on y1.ccn = y2.ccn;
quit;

data y1_ccns;
  set y1_y2 (where=(InY1 = 1 and InY2 = 0));
  keep Y1_CCN 
       y1_nhc24_prov_addr 
       y1_nhc24_prov_zip 
       y1_nhc24_prov_name
	   y1_nhc24_prov_type 
       y1_nhc24_resides_in_hospital 
       y1_nhc24_cont_care_rtrmnt_cmnty
	   y1_nhc24_avg_nmbr_res_per_day_fn 
       y1_nhc24_nmbr_crtfd_beds 
       y1_nhc24_ownership_type
	   y1_nhc24_changed_owner_lst12mnth
	   addr_zip
	   ;

  length addr_zip $75;

  addr_zip = catx('-', y1_nhc24_prov_addr, y1_nhc24_prov_zip);
run;

data y2_ccns;
  set y1_y2 (where=(InY1 = 0 and InY2 = 1));
  keep Y2_CCN 
       y2_nhc24_prov_addr 
       y2_nhc24_prov_zip 
       y2_nhc24_prov_name
	   y2_nhc24_prov_type 
       y2_nhc24_resides_in_hospital 
       y2_nhc24_cont_care_rtrmnt_cmnty
	   y2_nhc24_avg_nmbr_res_per_day_fn 
       y2_nhc24_nmbr_crtfd_beds 
       y2_nhc24_ownership_type
	   y2_nhc24_changed_owner_lst12mnth
	   addr_zip
	   ;

  length addr_zip $75;

  addr_zip = catx('-', y2_nhc24_prov_addr, y2_nhc24_prov_zip);
run;

proc sort data=y1_ccns; 
  by addr_zip; 
run;

proc sort data=y2_ccns; 
  by addr_zip; 
run;

data ccn_changed_same_addr;
  merge y1_ccns (in=y1)
        y2_ccns (in=y2);
  by addr_zip;
  if y1 and y2;
run;

proc sort data=ccn_changed_same_addr;
  by y2_ccn;
run;

***********************************************************************
*-- Flag the Y2 Sample Frame CCNs as same facility different CCN from 
    Y1 (CCN_CHNG) and keep the Y1 CCN (Y1_CCN).
*********************************************************************** ;

data y2_updated;
  merge y2 (in=y2)
        ccn_changed_same_addr (in=x keep=y1_ccn y2_ccn rename=(y2_ccn = ccn));
  by ccn;
  CCN_CHNG = 0;
  if x then CCN_CHNG = 1;

  label CCN_CHNG = "1=Facility changed CCN between Y1 and Y2"
        Y1_CCN = "Y1 CCN"
  ;
run;

***********************************************************************
*-- Key sample frame variables
*********************************************************************** ;

%let var_order = 
CCN
CCN_CHNG
Y1_CCN
SAME_FAC
SAME_FAC_ID
AVG_DAILY_CENSUS_ALL
AVG_DAILY_CENSUS_DMT
LTC_ALZUNIT_NMRC
LTC_PAYMCAID
NHC24_NMBR_CRTFD_BEDS
NHC24_PRIMARY_RUCA
NHC24_RURAL
MDS
HAS_NHC24
HAS_LTCF21
HAS_NHC22
;

***********************************************************************
*-- Variables to drop
*********************************************************************** ;

%let drop_vars = 
LTC_prov_name 
LTC_prov_addr
LTC_PROV_CITY 
LTC_prov_zip 
LTC_ALZUNIT
LTC_PROFIT
LTC_PROV_STATE 
LTC_PROV_CNTY_CD 
LTC_MSNG_ORIG_CCN
nhc22_legal_bus_name
nhc22_prov_name 
nhc22_prov_addr  
nhc22_prov_city  
nhc22_prov_state  
nhc22_prov_zip  
nhc22_prov_phone  
nhc22_prov_cnty_cd  
nhc22_prov_cnty_name  
nhc22_ownership_type  
nhc22_nmbr_crtfd_beds  
nhc22_prov_type  
nhc22_resides_in_hospital  
nhc22_cont_care_rtrmnt_cmnty  
nhc22_hlth_insp_gt_2yrs_ago   
nhc22_changed_owner_lst12mnths 
nhc22_month
nhc22_date_first_approved
SAME_FAC_ADDR                                                                                              
SAME_FAC_ID_ADDR                                                                                        
SAME_FAC_NAME                                                                                            
SAME_FAC_ID_NAME   
exclude
outofusa
;

***********************************************************************
*-- Drop variables and move the key sample frame variables to the front 
    of the file
*********************************************************************** ;

data &outfile.;
  retain &var_order.;
  set y2_updated (drop=&drop_vars. rename=(has_ltcf = HAS_LTCF21));

  label ccn = "CCN"
        same_fac = "1=CCN shares either the same zip and name or same zip and address with another CCN"                                                                                         
        same_fac_id = "Unique number assigned to all records with the same zip and name or same zip and address"                                                                                      
        ltc_alzunit_nmrc = "1=Facility has an Alzheimers disease special care unit"                                                                                
        ltc_paymcaid = "Proportion of facility residents whose primary support is Medicaid"                                                                                      
        nhc24_nmbr_crtfd_beds = "Number of Federally Certified Beds"                                                                             
        nhc24_primary_ruca = "Rural-urban commuting area (RUCA) codes"                                                                                
        nhc24_rural = "1=Census tract of the facility is in a rural area" 
        has_nhc24 = "1=CCN was found in Nursing Home Compare 2024"
        has_ltcf21 = "1=CCN was found in LTC Focus 2021"                                                                                          
        has_nhc22 = "1=CCN was found in Nursing Home Compare 2022"
		ccn_x_ownership = "1=CCN changed ownership between MDS 2022 and September NHC 2024"
		ccn22 = "The MDS 2022 CCN for facilities with CCN_X_OWNERSHIP = 1"
  ;
run;

***********************************************************************
*-- Output to Excel
*********************************************************************** ;

proc export data=&outfile.
			outfile=&xlsfile.
			dbms=xlsx
			label
			replace;
run;